package com.ruoyi.zongzhi.controller;

import java.util.List;
import io.swagger.annotations.Api;
import javax.servlet.http.HttpServletResponse;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.zongzhi.domain.TcNetworkEvaluate;
import com.ruoyi.zongzhi.service.ITcNetworkEvaluateService;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.common.core.page.TableDataInfo;

/**
 * 网评Controller
 * 
 * @author ruoyi
 * @date 2023-08-10
 */
@RestController
@RequestMapping("/zongzhi/evaluate")
@Api(tags = " 网评")
public class TcNetworkEvaluateController extends BaseController
{
    @Autowired
    private ITcNetworkEvaluateService tcNetworkEvaluateService;

    /**
     * 查询网评列表
     */

    @GetMapping("/list")
    public TableDataInfo list(TcNetworkEvaluate tcNetworkEvaluate)
    {
        startPage();
        List<TcNetworkEvaluate> list = tcNetworkEvaluateService.selectTcNetworkEvaluateList(tcNetworkEvaluate);
        return getDataTable(list);
    }

    /**
     * 导出网评列表
     */

    @PostMapping("/export")
    public void export(HttpServletResponse response, TcNetworkEvaluate tcNetworkEvaluate)
    {
        List<TcNetworkEvaluate> list = tcNetworkEvaluateService.selectTcNetworkEvaluateList(tcNetworkEvaluate);
        ExcelUtil<TcNetworkEvaluate> util = new ExcelUtil<TcNetworkEvaluate>(TcNetworkEvaluate.class);
        util.exportExcel(response, list, "网评数据");
    }

    /**
     * 获取网评详细信息
     */

    @GetMapping(value = "/{id}")
    public AjaxResult getInfo(@PathVariable("id") Long id)
    {
        return success(tcNetworkEvaluateService.selectTcNetworkEvaluateById(id));
    }

    /**
     * 新增网评
     */

    @PostMapping
    public AjaxResult add(@RequestBody TcNetworkEvaluate tcNetworkEvaluate)
    {
        tcNetworkEvaluate.setIsStatus(true);
        return toAjax(tcNetworkEvaluateService.insertTcNetworkEvaluate(tcNetworkEvaluate));
    }

    /**
     * 修改网评
     */


    @PutMapping
    public AjaxResult edit(@RequestBody TcNetworkEvaluate tcNetworkEvaluate)
    {
        return toAjax(tcNetworkEvaluateService.updateTcNetworkEvaluate(tcNetworkEvaluate));
    }

    /**
     * 删除网评
     */

	@DeleteMapping("/{ids}")
    public AjaxResult remove(@PathVariable Long[] ids)
    {
        return toAjax(tcNetworkEvaluateService.deleteTcNetworkEvaluateByIds(ids));
    }
}
